@@ -1,4 +1,14 @@
+//! Core types and abstractions used by the Rune ecosystem.
+//!
+//! # Feature Flags
+//!
+//! This crate has the following cargo feature flags:
+//!
+//! - `std` - enables functionality that requires the standard library
+//!   (typically implementations of `std::error::Error`)
+
 #![cfg_attr(not(feature = "std"), no_std)]
+#![cfg_attr(feature = "unstable_doc_cfg", feature(doc_cfg))]
 
 #[cfg(test)]
 #[macro_use]
@@ -28,6 +38,12 @@ pub use crate::{
 
 /// The mimetype used for a TensorFlow Lite model.
 pub const TFLITE_MIMETYPE: &str = "application/tflite-model";
+/// The mimetype used for a TensorFlow model.
+pub const TF_MIMETYPE: &str = "application/tf-model";
+/// The mimetype used for a ONNX model.
+pub const ONNX_MIMETYPE: &str = "application/onnx-model";
+/// The mimetype used for a TensorFlow JS model.
+pub const TFJS_MIMETYPE: &str = "application/tfjs-model";
 
 /// The version number for this crate.
 pub const VERSION: &str = env!("CARGO_PKG_VERSION");
